;Kepler Installer
;http://www.keplerproject.org
;Written by Danilo Tuler
;           Mauricio Bomfim

; Name of sections

!include "AdvReplaceInFile.nsi"
!define ALL_USERS
!include WriteEnvStr.nsh

;--------------------------------
;Include Modern UI

  !include "MUI.nsh"

;--------------------------------

; Section define/macro header file
; See this header file for more info

!include "Sections.nsh"

;--------------------------------
;General

  ;Version numbers
  !define VERSION "1.1 Beta 3 (work)"
  !define LUASOCKETVERSION "2.0.2"
  
  ;Name and file
  Name "Kepler"
  OutFile "..\kepler-${VERSION}.exe"

  ;Default installation folder
  InstallDir "c:\Kepler\1.1"
  
  ;Default Lua installation folder
  !define LUADIR "c:\lua5.1"
  
  ;Get installation folder from registry if available
  InstallDirRegKey HKCU "Software\Kepler" ""
  
  SetCompressor /SOLID lzma

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING
  !define MUI_ICON kepler.ico
  !define MUI_UNICON kepler.ico
  !define MUI_HEADERIMAGE
    !define MUI_HEADERIMAGE_BITMAP win\top_logo.bmp
      !define MUI_HEADERIMAGE_BITMAP_NOSTRETCH
    !define MUI_HEADERIMAGE_UNBITMAP win\top_logo.bmp
      !define MUI_HEADERIMAGE_UNBITMAP_NOSTRETCH
  !define MUI_COMPONENTSPAGE_SMALLDESC
  ;!define MUI_COMPONENTSPAGE_NODESC

;--------------------------------
;Language Selection Dialog Settings

  ;Remember the installer language
  !define MUI_LANGDLL_REGISTRY_ROOT "HKCU" 
  !define MUI_LANGDLL_REGISTRY_KEY "Software\Kepler" 
  !define MUI_LANGDLL_REGISTRY_VALUENAME "Installer Language"

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_LICENSE "license.txt"
  !insertmacro MUI_PAGE_COMPONENTS
  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES

;--------------------------------
;Languages

  !insertmacro MUI_LANGUAGE "English"
  !insertmacro MUI_LANGUAGE "Spanish"
  !insertmacro MUI_LANGUAGE "PortugueseBR"

;--------------------------------
;Reserve Files
  
  ;These files should be inserted before other files in the data block
  ;Keep these lines before any File command
  ;Only for solid compression (by default, solid compression is enabled for BZIP2 and LZMA)
  
  !insertmacro MUI_RESERVEFILE_LANGDLL

;--------------------------------
;Version Information

  VIProductVersion "1.1.0.0"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "ProductName" "Kepler"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "Comments" "Lua Web Development Platform"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "CompanyName" "Kepler Project"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "LegalTrademarks" ""
  VIAddVersionKey /LANG=${LANG_ENGLISH} "LegalCopyright" " 2003-2007 Kepler Project"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "FileDescription" "Kepler Installer"
  VIAddVersionKey /LANG=${LANG_ENGLISH} "FileVersion" "1.1.0.0"

;--------------------------------
;Installer Sections

InstType "Full"

SubSection "Platform Files" SubSectionPlatform

	SubSection "Core Files" SubSectionCore

		Section "Lua" SectionLua
			SectionIn 1 RO
			
			SetOutPath "$INSTDIR\bin"
	
			File /a ${LUADIR}\lua5.1.dll
			File /a ${LUADIR}\lua5.1.exe  
			File /a ${LUADIR}\luac5.1.exe 
			File /a ${LUADIR}\bin2c5.1.exe

			Push "KEPLER_INIT"
			Push "$INSTDIR\bin\kepler_init.lua"
			Call WriteEnvStr

			# menu
			CreateDirectory "$SMPROGRAMS\Kepler"
			CreateShortCut "$SMPROGRAMS\Kepler\Uninstall.lnk" "$INSTDIR\Uninstall.exe"
			
			# registry
			;Store installation folder
			WriteRegStr HKCU "Software\Kepler" "" $INSTDIR
	
			;Create uninstaller
			WriteUninstaller "$INSTDIR\Uninstall.exe"
		SectionEnd
		
		Section "LuaFilesystem" SectionLuaFilesystem
			SectionIn 1 RO
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\lfs.dll
            
            SetOutPath "$INSTDIR\web\doc\luafilesystem"
            File ..\luafilesystem\doc\us\*.*
            
		SectionEnd
        
        Section "Rings" SectionRings
			SectionIn 1 RO
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\rings.dll
			
			SetOutPath "$INSTDIR\lua"
			File /a ${LUADIR}\lua\stable.lua
            
            SetOutPath "$INSTDIR\web\doc\rings"
            File ..\rings\doc\us\*.*
            
		SectionEnd
	
		Section "LuaSocket" SectionLuaSocket
			SectionIn 1 RO
			SetOutPath "$INSTDIR\bin\socket"
			File /a ${LUADIR}\socket\core.dll
            
            SetOutPath "$INSTDIR\bin\mime"
			File /a ${LUADIR}\mime\core.dll

			SetOutPath "$INSTDIR\lua"
			File /a ${LUADIR}\lua\ltn12.lua
            File /a ${LUADIR}\lua\socket.lua
            File /a ${LUADIR}\lua\mime.lua			

            SetOutPath "$INSTDIR\web\doc\kepler"
            File ..\doc\us\*.*
            			
			SetOutPath "$INSTDIR\lua\socket"
			File /a ${LUADIR}\lua\socket\ftp.lua
			File /a ${LUADIR}\lua\socket\http.lua
			File /a ${LUADIR}\lua\socket\smtp.lua
			File /a ${LUADIR}\lua\socket\tp.lua
			File /a ${LUADIR}\lua\socket\url.lua
            
            SetOutPath "$INSTDIR\web\doc\luasocket"
            File ..\luasocket-${LUASOCKETVERSION}\doc\*.*
            
			# TODO: mbox.lua ?
		
		SectionEnd
	
		       
        Section "CGILua" SectionCGILua
            SectionIn 1 RO
            CreateDirectory $INSTDIR\apps
            CreateDirectory $INSTDIR\apps\cgilua
            CreateDirectory $INSTDIR\conf
            CreateDirectory $INSTDIR\conf\cgilua
            CreateDirectory $INSTDIR\tmp
            ; TODO test scripts
            ; TODO docs
            
            SetOutPath "$INSTDIR\lua"
            File /a ${LUADIR}\lua\cgilua.lua

            SetOutPath "$INSTDIR\lua\cgilua"
            File /a ${LUADIR}\lua\cgilua\*.lua
            
            SetOutPath "$INSTDIR\conf\cgilua"
            SetOverwrite off
            File /a ..\src\cgilua\config.lua
            SetOverwrite on

            SetOutPath "$INSTDIR\web\doc\cgilua"
            File ..\cgilua\doc\us\*.*
            
        SectionEnd
        
       
    SubSectionEnd #Core

    SubSection "Libraries" SubSectionLibraries

		Section "LuaCOM" SectionLuaCOM
			SectionIn 1 RO
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\luacom.dll
		SectionEnd

        Section "LuaZip" SectionLuaZip
            SectionIn 1 RO
            SetOutPath "$INSTDIR\bin"
            File /a ${LUADIR}\zip.dll
            
            SetOutPath "$INSTDIR\web\doc\luazip"
            File ..\luazip\doc\us\*.*
            
        SectionEnd

        Section "LuaExpat" SectionLuaExpat
            SectionIn 1 RO
            SetOutPath "$INSTDIR\bin"
            File /a ${LUADIR}\lxp.dll
    
            SetOutPath "$INSTDIR\bin"
            File /a ${LUADIR}\libexpat.dll
        
            SetOutPath "$INSTDIR\lua\lxp"
            File /a ${LUADIR}\lua\lxp\lom.lua
            
            SetOutPath "$INSTDIR\web\doc\luaexpat"
            File ..\luaexpat\doc\us\*.*
        SectionEnd

        Section "LuaLogging" SectionLuaLogging
            SectionIn 1 RO
            SetOutPath "$INSTDIR\lua"
            File /a ${LUADIR}\lua\logging.lua
            SetOutPath "$INSTDIR\lua\logging"
            File /a ${LUADIR}\lua\logging\*.lua

            SetOutPath "$INSTDIR\web\doc\lualogging"
            File ..\lualogging\doc\us\*.*
        SectionEnd

         Section "LuaMD5" SectionLuaMD5
			SectionIn 1 RO
            SetOutPath "$INSTDIR\bin"
            File /a ${LUADIR}\des56.dll
            
            SetOutPath "$INSTDIR\bin\md5"
			File /a ${LUADIR}\md5\core.dll
				
			SetOutPath "$INSTDIR\lua"
			File /a ${LUADIR}\lua\md5.lua

            SetOutPath "$INSTDIR\web\doc\md5"
            File ..\md5\doc\us\*.*
        SectionEnd
    SubSectionEnd #Libraries
    
   
   
   
   
   Section "KeplerInit" SectionKeplerInit
        SectionIn 1 RO
   
		# kepler_init.lua
		SetOutPath "$INSTDIR\bin"
		File /a /oname=kepler_init.lua ..\src\t_kepler_init.lua
		
        Push "[[LIB_EXT]]"          #-- text to be replaced  within the " "
        Push [[dll]]        #-- replace with anything within the " "
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function

        Push "[[KEPLER_APPS]]"        #-- text to be replaced  within the " "
        Push [[$INSTDIR\apps]]        #-- replace with anything within the " "      
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua        #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function
                
        Push "[[KEPLER_CONF]]"        #-- text to be replaced  within the " "
		Push [[$INSTDIR\conf]]        #-- replace with anything within the " "		
		Push all                      #-- replace all occurrences
		Push all                      #-- replace all occurrences
		Push $INSTDIR\bin\kepler_init.lua        #-- file to replace in
		Call AdvReplaceInFile         #-- Call the Function

        Push "[[KEPLER_LOG]]"        #-- text to be replaced  within the " "
        Push [[$INSTDIR\log]]        #-- replace with anything within the " "      
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua        #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function
	        
        Push "[[KEPLER_LIB]]"          #-- text to be replaced  within the " "
        Push [[$INSTDIR\bin]]         #-- replace with anything within the " "
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function

        Push "[[KEPLER_LUA]]"          #-- text to be replaced  within the " "
        Push [[$INSTDIR\lua]]         #-- replace with anything within the " "
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function
                
        Push "[[KEPLER_TMP]]"        #-- text to be replaced  within the " "
        Push [[$INSTDIR\tmp]]        #-- replace with anything within the " "      
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua        #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function
    
        Push "[[KEPLER_WEB]]"        #-- text to be replaced  within the " "
        Push [[$INSTDIR\web]]        #-- replace with anything within the " "      
        Push all                      #-- replace all occurrences
        Push all                      #-- replace all occurrences
        Push $INSTDIR\bin\kepler_init.lua        #-- file to replace in
        Call AdvReplaceInFile         #-- Call the Function
   
   SectionEnd
   
   
 
SubSectionEnd #Platform


   	SubSection /e "Launchers" SubSectionCGILua
		
		Section "CGI" SectionCGI
			SectionIn 1
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\cgi.exe
            File /a /oname=cgi.cgi ..\wsapi\src\sapi\t_cgi
            SetOutPath "$INSTDIR\lua\wsapi"
            File /a ${LUADIR}\lua\wsapi\*.lua
            
			Push "[[KEPLER_INIT]]"           #-- text to be replaced  within the " "
			Push [[$INSTDIR\bin\kepler_init.lua]] #-- replace with anything within the " "
			Push all                      #-- replace all occurrences
			Push all                      #-- replace all occurrences
			Push $INSTDIR\bin\cgi.cgi #-- file to replace in
			Call AdvReplaceInFile         #-- Call the Function	
            
		SectionEnd
		
		/*Section "FastCGI" SectionFastCGI
			SectionIn 1
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\fastcgi.exe
			File /a ${LUADIR}fcgi.dll
			File /a /oname=fastcgi.conf ${LUADIR}\t_fastcgi.conf
			
			Push "FCGI_DIR/fastcgi"            #-- text to be replaced  within the " "
			Push '"$INSTDIR\fastcgi.exe"'  #-- replace with anything within the " "
			Push all                           #-- replace all occurrences
			Push all                           #-- replace all occurrences
			Push "$INSTDIR\fastcgi.conf"   #-- file to replace in
			Call AdvReplaceInFile              #-- Call the Function
		
			Push "FastCgiIpcDir FCGI_DIR/tmp"  #-- text to be replaced  within the " "
			Push "#FastCgiIpcDir FCGI_DIR/tmp" #-- replace with anything within the " "
			Push all                           #-- replace all occurrences
			Push all                           #-- replace all occurrences
			Push "$INSTDIR\fastcgi.conf"   #-- file to replace in
			Call AdvReplaceInFile              #-- Call the Function
		
			Push "ScriptAlias   /fcgi/       FCGI_DIR/"        #-- text to be replaced  within the " "
			Push 'ScriptAlias   /fcgi/       "$INSTDIR\web\"'  #-- replace with anything within the " "
			Push all                                           #-- replace all occurrences
			Push all                                           #-- replace all occurrences
			Push "$INSTDIR\fastcgi.conf"                       #-- file to replace in
			Call AdvReplaceInFile                              #-- Call the Function
		SectionEnd*/
		
		/*Section "ISAPI" SectionISAPI
			SectionIn 1
			SetOutPath "$INSTDIR\bin"
			File /a ${LUADIR}\cgilua_isapi.dll
		SectionEnd*/
		
		/*Section "Apache Module" SectionMod
			SectionIn 1
			SetOutPath "$INSTDIR"
			File /a ${LUADIR}\mod_lua.so
			File /a /oname=mod2.conf ${LUADIR}\t_mod2.conf
            SetOutPath "$INSTDIR\lua\sapi\mod2"
            File /a ${LUADIR}\lua\sapi\mod2\*.lua

			Push "CGILUA_DIR/"            #-- text to be replaced  within the " "
			Push "$INSTDIR\"              #-- replace with anything within the " "
			Push all                      #-- replace all occurrences
			Push all                      #-- replace all occurrences
			Push $INSTDIR\mod2.conf       #-- file to replace in
			Call AdvReplaceInFile         #-- Call the Function
		SectionEnd*/
	
		Section "Xavante" SectionXavante
			SectionIn 1
			CreateDirectory $INSTDIR\web
            CreateDirectory $INSTDIR\web\css
			CreateDirectory $INSTDIR\web\img
			CreateDirectory $INSTDIR\web\doc
			CreateDirectory $INSTDIR\log
			CreateDirectory $INSTDIR\conf\xavante

            SetOutPath "$INSTDIR\bin"
			CreateShortCut "$SMPROGRAMS\Kepler\Xavante.lnk" "$INSTDIR\bin\xavante.exe" "--start" "$INSTDIR\bin\xavante.exe" 1 SW_SHOWNORMAL ALT|CTRL|SHIFT|F5 "Run Xavante Web Server"
			CreateShortCut "$DESKTOP\Xavante.lnk" "$INSTDIR\bin\xavante.exe" "--start" "$INSTDIR\bin\xavante.exe" 1 SW_SHOWNORMAL ALT|CTRL|SHIFT|F5 "Run Xavante Web Server"
		
			SetOutPath "$INSTDIR\bin"
			File /a /oname=xavante_start ..\src\t_xavante_start
			File /a ${LUADIR}\xavante.exe
		
			SetOutPath "$INSTDIR\lua"
			File ${LUADIR}\lua\copas.lua
            
            SetOutPath "$INSTDIR\web\doc\copas"
            File ..\copas\doc\us\*.*
		
			SetOutPath "$INSTDIR\lua"
			File ${LUADIR}\lua\coxpcall.lua
		
			SetOutPath "$INSTDIR\lua"
			File ${LUADIR}\lua\sajax.lua
		
            SetOutPath "$INSTDIR\lua"
            File ${LUADIR}\lua\xavante.lua
			SetOutPath "$INSTDIR\lua\xavante"
			File ${LUADIR}\lua\xavante\*.lua
		
			SetOutPath "$INSTDIR\web"
            File ..\web\*.lp
            File ..\web\*.lua
		
            SetOutPath "$INSTDIR\web\css"
            File ..\web\css\*.css
            
            SetOutPath "$INSTDIR\web\img"
			File ..\web\img\*.jpg
			File ..\web\img\*.gif
		
			SetOutPath "$INSTDIR\web\doc\xavante"
			File ..\xavante\doc\us\*.*
		
			SetOutPath "$INSTDIR\conf\xavante"
			SetOverwrite off
			File /a ..\src\xavante\config.lua
			SetOverwrite on

			Push "[[KEPLER_INIT]]"           #-- text to be replaced  within the " "
			Push [[$INSTDIR\bin\kepler_init.lua]] #-- replace with anything within the " "
			Push all                      #-- replace all occurrences
			Push all                      #-- replace all occurrences
			Push $INSTDIR\bin\xavante_start #-- file to replace in
			Call AdvReplaceInFile         #-- Call the Function		
			
		SectionEnd
	
	SubSectionEnd #CGILua
		
	SubSection /e "Database" SubSectionLuaSQL
	
		; TODO remove bug in selective install option
		; currently its impossible to select neither option
		; check: http://nsis.sourceforge.net/archive/nsisweb.php?page=85&instances=0,64
		/*Section /o "MySQL 4.0" SectionMySQL40
			SetOutPath "$INSTDIR\luasql"
#			SectionIn
			File /a /oname=mysql.dll ${LUADIR}\luasql\mysql40.dll
		SectionEnd*/
	
		/*Section "MySQL 4.1" SectionMySQL41
			SetOutPath "$INSTDIR\luasql"
#			SectionIn 1
			File /a /oname=mysql.dll ${LUADIR}\luasql\mysql41.dll
		SectionEnd*/
	
		Section "MySQL 5.0" SectionMySQL50
			SetOutPath "$INSTDIR\bin\luasql"
			SectionIn 1
			File /a ${LUADIR}\luasql\mysql.dll
            
            SetOutPath "$INSTDIR\web\doc\luasql"
            File ..\luasql\doc\us\*.*
		SectionEnd
	
		/*Section "ADO" SectionADO
			SetOutPath "$INSTDIR\lua\luasql"
			SectionIn 1
			File /a ${LUADIR}\lua\luasql\ado.lua
		SectionEnd*/

        Section "ODBC" SectionODBC
			SetOutPath "$INSTDIR\bin\luasql"
			SectionIn 1
			File /a ${LUADIR}\luasql\odbc.dll
            SetOutPath "$INSTDIR\web\doc\luasql"
            File ..\luasql\doc\us\*.*
		SectionEnd
	
		/*Section "Postgres" SectionPostgres
			SectionIn 1
			SetOutPath "$INSTDIR\bin\luasql"
			File /a ${LUADIR}\luasql\postgres.dll
		SectionEnd*/
	
		Section "SQLite" SectionSQLite
			SectionIn 1
			SetOutPath "$INSTDIR\bin\luasql"
			File /a ${LUADIR}\luasql\sqlite3.dll
			; TODO compile sqlite.dll dynamicly
            SetOutPath "$INSTDIR\web\doc\luasql"
            File ..\luasql\doc\us\*.*
		SectionEnd
	
		/*Section "Oracle (OCI8)" SectionOCI8
			SectionIn 1
			SetOutPath "$INSTDIR\bin\luasql"
			File /a ${LUADIR}\luasql\oci8.dll
		SectionEnd*/
	
	SubSectionEnd #LuaSQL

;--------------------------------
;Installer Functions

Function .onInit

  !insertmacro MUI_LANGDLL_DISPLAY
  ; StrCpy $1 ${SectionMySQL50} ; SectionMySQL50 is selected by default

FunctionEnd


;--------------------------------
;Descriptions

  ;USE A LANGUAGE STRING IF YOU WANT YOUR DESCRIPTIONS TO BE LANGAUGE SPECIFIC

  ;Assign descriptions to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SubSectionCore} "Kepler Core Components"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLua} "Lua 5.1.2 (LuaBinaries) (http://luabinaries.luaforge.net/)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaSocket} "LuaSocket 2.0.2 (http://luasocket.luaforge.net/)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaFilesystem} "LuaFileSystem 1.2.1 (http://www.keplerproject.org/luafilesystem)"
	!insertmacro MUI_DESCRIPTION_TEXT ${SectionRings} "Rings 1.1.0 (http://http://www.keplerproject.org/rings/)"
	!insertmacro MUI_DESCRIPTION_TEXT ${SubSectionLibraries} "Kepler Libraries"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaCOM} "LuaCOM 1.3 (http://www.tecgraf.puc-rio.br/~rcerq/luacom/)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaZip} "LuaZip 1.2.3 (http://www.keplerproject.org/luazip)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaExpat} "LuaExpat 1.1.0 (http://www.keplerproject.org/luaexpat)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaLogging} "LuaLogging 1.1.3 (http://www.keplerproject.org/lualogging)"
	!insertmacro MUI_DESCRIPTION_TEXT ${SectionLuaMD5} "MD5 1.1.0 (http://www.keplerproject.org/md5/)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SubSectionLuaSQL} "LuaSQL 2.1.0 (http://www.keplerproject.org/luasql)"
;    !insertmacro MUI_DESCRIPTION_TEXT ${SectionMySQL} "MySQL Driver"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionMySQL40} "MySQL 4.0.26 Driver"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionMySQL41} "MySQL 4.1.16 Driver"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionMySQL50} "MySQL 5.0.20a Driver"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionADO} "ADO Driver"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionODBC} "ODBC Driver"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionPostgres} "Postgres Driver"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionSQLite} "SQLite 3.3.17 Driver"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionOCI8} "Oracle Driver (OCI8)"
    
    !insertmacro MUI_DESCRIPTION_TEXT ${SubSectionCGILua} "CGILua 5.1.0 (http://www.keplerproject.org/cgilua)"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionCGILua} "CGILua Core Files"
    !insertmacro MUI_DESCRIPTION_TEXT ${SectionCGI} "CGI Launcher"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionFastCGI} "FastCGI Launcher"
    ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionISAPI} "ISAPI Launcher"
     ;!insertmacro MUI_DESCRIPTION_TEXT ${SectionMod} "Apache Module Launcher"
	!insertmacro MUI_DESCRIPTION_TEXT ${SectionXavante} "Xavante 1.3.2 (http://www.keplerproject.org/xavante/)"
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

 
;--------------------------------
;Uninstaller Section

Section "Uninstall"
	Delete $INSTDIR\Uninstall.exe
	RMDir /r /REBOOTOK $INSTDIR
	RMDir /r /REBOOTOK $INSTDIR\lua
	RMDir $INSTDIR\conf\cgilua
	RMDir $INSTDIR\conf\xavante
	RMDir $INSTDIR\conf
	RMDir $INSTDIR\tmp
	RMDir $INSTDIR\web
	RMDir $INSTDIR\log
	Delete /REBOOTOK $INSTDIR\*.*
	RMDir $INSTDIR
	
	Delete "$INSTDIR\bin\kepler_init.lua"
	Delete "$INSTDIR\Uninstall.exe"
	
	Delete "$SMPROGRAMS\Kepler\Uninstall.lnk"
	Delete "$SMPROGRAMS\Kepler\xavante.lnk"
	Delete "$DESKTOP\xavante.lnk"
	RMDir $SMPROGRAMS\Kepler
	
	# remove the variable
	Push "KEPLER_INIT"
	Call un.DeleteEnvStr

	DeleteRegKey /ifempty HKCU "Software\Kepler"
	DeleteRegKey /ifempty HKLM "Software\CGILua"
SectionEnd

;--------------------------------
;Uninstaller Functions

Function un.onInit

  !insertmacro MUI_UNGETLANGUAGE
  
FunctionEnd

